@@ -29,6 +29,62 @@ class KbiLanguageModel(BaseLanguageModel):
 			*args,
 			**kwargs
 	):
+		r"""
+		Knowledge-Base Inference Language Model for Attitude Consistency Scoring.
+
+		Args:
+
+			ke: Knowledge Embedding model to use for model.
+
+			infer: Attitude Consistency Scoring module to use for stance inference.
+
+			threshold: Threshold module to use for system predictions.
+
+			metric: Metric to evaluate overall performance. Typically Macro or Micro F1.
+
+			m_metric: Metric to optimize for each Stance Knowledge Graph threshold, typically Micro F1.
+
+			num_relations: Number of different relations, such as "Agree" and "Disagree".
+				Default: ``2``.
+
+			num_classes: Number of different classes, such as "Accept", "Reject", and "No Stance".
+				Default: ``3``.
+
+			num_val_seeds: Number of validation examples to leave out during threshold update.
+				Default: ``1``.
+
+			num_threshold_steps: Number of different threshold values to evaluate when updating threshold on
+				validation dataset.
+				Default: ``100``.
+
+			update_threshold: If ``False``, validation thresholds are not updated. Use this in testing.
+				Default: ``True``.
+
+			pre_model_name: Name of pre-trained model from huggingface. See https://huggingface.co/
+
+			pre_model_type: Type of pre-trained model.
+				Default: [`AutoModel`].
+
+			learning_rate: Maximum learning rate. Learning rate will warm up from ``0`` to ``learning_rate`` over
+				``lr_warm_up`` training steps, and will then decay from ``learning_rate`` to ``0`` linearly over the remaining
+				``1.0-lr_warm_up`` training steps.
+
+			weight_decay: How much weight decay to apply in the AdamW optimizer.
+				Default: ``0.0``.
+
+			lr_warm_up: The percent of training steps to warm up learning rate from ``0`` to ``learning_rate``.
+				Default: ``0.1``.
+
+			load_pre_model: If ``False``, Model structure will load from pre_model_name, but weights will not be initialized.
+				Cuts down on model load time if you plan on loading your model from a checkpoint, as there is no reason to
+				initialize your model twice.
+				Default: ``True``.
+
+			torch_cache_dir: If provided, cache directory for loading models. Defaults to huggingface default.
+				Default: ``None``.
+
+		"""
+
 		super().__init__(*args, **kwargs)
 		self.num_relations = num_relations
 		self.num_classes = num_classes
